Analysis: A little analyisis that need to be deeper Calculate the...

Description Usage Arguments Examples

View source: R/Analysis.R

Description

A little analyisis that need to be deeper Calculate the RollingMEan and Analyze keys statistics

Usage

1

Arguments

variable

(usually, multi table xts)

Examples

1
Summary <- Analysis(ClosingPrices)

unimi-dse/edf3d358 documentation built on Feb. 19, 2020, 10:43 p.m.